@@ -11,9 +11,10 @@
 // General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, see <http://www.gnu.org/licenses/>.
+// along with this program; if not, see <https://www.gnu.org/licenses/>.
 
 #include <apertium/tagger.h>
+#include <lttoolbox/lt_locale.h>
 
 #include "getopt_long.h"
 #include <cerrno>
@@ -30,10 +31,11 @@
 #include <unistd.h>
 
 int main(int argc, char **argv) {
+  LtLocale::tryToSetLocale();
   try {
     Apertium::apertium_tagger(argc, argv);
   } catch (const Apertium::Exception::apertium_tagger::err_Exception &err_Exception_) {
-    std::wcerr << "Try 'apertium-tagger --help' for more information." << std::endl;
+    std::cerr << "Try 'apertium-tagger --help' for more information." << std::endl;
     return 1;
   } catch (...) {
     throw;
